IndexerClient

Struct IndexerClient 

pub struct IndexerClient<T> {
    inner: Grpc<T>,
}

Fields

inner: Grpc<T>

Implementations

Source

impl IndexerClient<Channel>

pub async fn connect<D>(dst: D) -> Result<Self, Error>
where D: TryInto<Endpoint>, D::Error: Into<StdError>,

Attempt to create a new client by connecting to a given endpoint.

Source

impl<T> IndexerClient<T>
where T: GrpcService<Body>, T::Error: Into<StdError>, T::ResponseBody: Body<Data = Bytes> + Send + 'static, <T::ResponseBody as Body>::Error: Into<StdError> + Send,

pub fn new(inner: T) -> Self

pub fn with_origin(inner: T, origin: Uri) -> Self

pub fn with_interceptor<F>( inner: T, interceptor: F, ) -> IndexerClient<InterceptedService<T, F>>
where F: Interceptor, T::ResponseBody: Default, T: Service<Request<Body>, Response = Response<<T as GrpcService<Body>>::ResponseBody>>, <T as Service<Request<Body>>>::Error: Into<StdError> + Send + Sync,

pub fn send_compressed(self, encoding: CompressionEncoding) -> Self

Compress requests with the given encoding.

This requires the server to support it otherwise it might respond with an error.

pub fn accept_compressed(self, encoding: CompressionEncoding) -> Self

Enable decompressing responses.

pub fn max_decoding_message_size(self, limit: usize) -> Self

Limits the maximum size of a decoded message.

Default: 4MB

pub fn max_encoding_message_size(self, limit: usize) -> Self

Limits the maximum size of an encoded message.

Default: usize::MAX

pub async fn chain_tip_change( &mut self, request: impl IntoRequest<Empty>, ) -> Result<Response<Streaming<BlockHashAndHeight>>, Status>

Notifies listeners of chain tip changes

pub async fn non_finalized_state_change( &mut self, request: impl IntoRequest<NonFinalizedStateChangeRequest>, ) -> Result<Response<Streaming<BlockAndHash>>, Status>

Notifies listeners of new blocks in the non-finalized state.

Callers may provide the hashes of the chain tips they already have so the server only streams blocks after those tips. An empty request streams every block currently in the non-finalized state.

pub async fn mempool_change( &mut self, request: impl IntoRequest<Empty>, ) -> Result<Response<Streaming<MempoolChangeMessage>>, Status>

Notifies listeners of mempool changes

pub async fn get_block( &mut self, request: impl IntoRequest<BlockRequest>, ) -> Result<Response<BlockAndHash>, Status>

Returns the block with the given hash or height from the best chain.

Used by a syncer to fetch finalized blocks that bridge the gap between its local finalized tip and the start of the streamed non-finalized chain.