pub struct IndexerClient<T> {
inner: Grpc<T>,
}Fields
inner: Grpc<T>Implementations
Sourceimpl IndexerClient<Channel>
impl IndexerClient<Channel>
Sourceimpl<T> IndexerClient<T>
impl<T> IndexerClient<T>
pub fn new(inner: T) -> Self
pub fn with_origin(inner: T, origin: Uri) -> Self
pub fn with_interceptor<F>( inner: T, interceptor: F, ) -> IndexerClient<InterceptedService<T, F>>
Sourcepub fn send_compressed(self, encoding: CompressionEncoding) -> Self
pub fn send_compressed(self, encoding: CompressionEncoding) -> Self
Compress requests with the given encoding.
This requires the server to support it otherwise it might respond with an error.
Sourcepub fn accept_compressed(self, encoding: CompressionEncoding) -> Self
pub fn accept_compressed(self, encoding: CompressionEncoding) -> Self
Enable decompressing responses.
Sourcepub fn max_decoding_message_size(self, limit: usize) -> Self
pub fn max_decoding_message_size(self, limit: usize) -> Self
Limits the maximum size of a decoded message.
Default: 4MB
Sourcepub fn max_encoding_message_size(self, limit: usize) -> Self
pub fn max_encoding_message_size(self, limit: usize) -> Self
Limits the maximum size of an encoded message.
Default: usize::MAX
Sourcepub async fn chain_tip_change(
&mut self,
request: impl IntoRequest<Empty>,
) -> Result<Response<Streaming<BlockHashAndHeight>>, Status>
pub async fn chain_tip_change( &mut self, request: impl IntoRequest<Empty>, ) -> Result<Response<Streaming<BlockHashAndHeight>>, Status>
Notifies listeners of chain tip changes
Sourcepub async fn non_finalized_state_change(
&mut self,
request: impl IntoRequest<NonFinalizedStateChangeRequest>,
) -> Result<Response<Streaming<BlockAndHash>>, Status>
pub async fn non_finalized_state_change( &mut self, request: impl IntoRequest<NonFinalizedStateChangeRequest>, ) -> Result<Response<Streaming<BlockAndHash>>, Status>
Notifies listeners of new blocks in the non-finalized state.
Callers may provide the hashes of the chain tips they already have so the server only streams blocks after those tips. An empty request streams every block currently in the non-finalized state.
Sourcepub async fn mempool_change(
&mut self,
request: impl IntoRequest<Empty>,
) -> Result<Response<Streaming<MempoolChangeMessage>>, Status>
pub async fn mempool_change( &mut self, request: impl IntoRequest<Empty>, ) -> Result<Response<Streaming<MempoolChangeMessage>>, Status>
Notifies listeners of mempool changes
Sourcepub async fn get_block(
&mut self,
request: impl IntoRequest<BlockRequest>,
) -> Result<Response<BlockAndHash>, Status>
pub async fn get_block( &mut self, request: impl IntoRequest<BlockRequest>, ) -> Result<Response<BlockAndHash>, Status>
Returns the block with the given hash or height from the best chain.
Used by a syncer to fetch finalized blocks that bridge the gap between its local finalized tip and the start of the streamed non-finalized chain.